#ifndef NT2_INCLUDE_CONSTANTS_MAXLOG_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MAXLOG_HPP_INCLUDED

#include <nt2/exponential/include/constants/maxlog.hpp>

#endif
